@@ -10,7 +10,7 @@
 #' @param x a (non-empty) numeric vector of data values.
 #' @param na.rm logical. Should missing values be removed?
 #' @param ... passed to [`mllogis`][mllogis].
-#' @return `mlllogis` returns an object of [class][base::class] `univariateML`.
+#' @return `mllogis` returns an object of [class][base::class] `univariateML`.
 #'    This is a named numeric vector with maximum likelihood estimates for
 #'    `shape` and `rate` and the following attributes:
 #'     \item{`model`}{The name of the model.}
@@ -31,27 +31,22 @@
 #' Dutang, C., Goulet, V., & Pigeon, M. (2008). actuar: An R package for
 #' actuarial science. Journal of Statistical Software, 25(7), 1-37.
 #' @export
+mlllogis <- function(x, na.rm = FALSE, ...) {}
 
-mlllogis <- function(x, na.rm = FALSE, ...) {
-  if (na.rm) x <- x[!is.na(x)] else assertthat::assert_that(!anyNA(x))
-  ml_input_checker(x)
-  assertthat::assert_that(min(x) > 0)
+univariateML_metadata$mlllogis <- list(
+  "model" = "Loglogistic",
+  "density" = "actuar::dllogis",
+  "support" = intervals::Intervals(c(0, Inf), closed = c(TRUE, FALSE)),
+  "names" = c("shape", "rate"),
+  "default" = c(1, 2)
+)
 
+mlllogis_ <- function(x, ...) {
   y <- log(x)
-
-  object <- mllogis(y)
-  object[1] <- exp(-object[1])
-  object[2] <- 1 / object[2]
-  object <- rev(object)
-  class(object) <- "univariateML"
-  names(object) <- c("shape", "rate")
-
-  attr(object, "model") <- "Loglogistic"
-  attr(object, "density") <- "actuar::dllogis"
-  attr(object, "n") <- length(x)
-  attr(object, "logLik") <-
-    sum(actuar::dllogis(x, object[1], object[2], log = TRUE))
-  attr(object, "support") <- c(0, Inf)
-  attr(object, "call") <- match.call()
-  object
+  estimates <- mllogis_(y)$estimates
+  estimates[1] <- exp(-estimates[1])
+  estimates[2] <- 1 / estimates[2]
+  estimates <- rev(estimates)
+  logLik <- sum(actuar::dllogis(x, estimates[1], estimates[2], log = TRUE))
+  list(estimates = estimates, logLik = logLik)
 }
