@@ -31,20 +31,3 @@ expect_equal(coef(mlbeta(small_data, type = "gradient")),
 expect_error(mlbeta(c(0, tiny_data)))
 expect_error(mlbeta(c(tiny_data, 1)))
 expect_error(mlbeta(c(tiny_data, NA)))
-
-## Checks that na.rm works as intended.
-expect_equal(
-  coef(mlbeta(small_data)),
-  coef(mlbeta(c(small_data, NA), na.rm = TRUE))
-)
-
-## Is the log-likelihood correct?
-est <- mlbeta(small_data, na.rm = TRUE)
-expect_equal(
-  sum(dbeta(small_data, est[1], est[2], log = TRUE)),
-  attr(est, "logLik")
-)
-
-## Check class.
-expect_equal(attr(est, "model"), "Beta")
-expect_equal(class(est), "univariateML")
