@@ -25,3 +25,7 @@ expect_equal(
 ## Check class.
 expect_equal(attr(est, "model"), "Exponential")
 expect_equal(class(est), "univariateML")
+
+
+## Check support.
+expect_equal(class(attr(est, "support"))[[1]], "numeric")
