@@ -47,3 +47,8 @@ expect_equal(
 ## Check class.
 expect_equal(attr(est, "model"), "Generalized Error")
 expect_equal(class(est), "univariateML")
+
+
+
+## Check support.
+expect_equal(class(attr(est, "support"))[[1]], "numeric")
